@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate;
-$App::SpreadRevolutionaryDate::VERSION = '0.38';
+$App::SpreadRevolutionaryDate::VERSION = '0.39';
 # ABSTRACT: Spread date and time from Revolutionary (Republican) Calendar on Bluesky, Twitter, Mastodon, Freenode and Liberachat.
 
 use Moose;
@@ -78,9 +78,9 @@ sub BUILD {
 sub spread {
   my $self = shift;
 
-  my $msg = $self->msgmaker->compute();
+  my ($msg, $img) = $self->msgmaker->compute();
   foreach my $target (@{$self->config->targets}) {
-    $self->targets->{$target}->spread($msg, $self->config->test);
+    $self->targets->{$target}->spread($msg, $self->config->test, $img);
   }
 }
 
@@ -107,7 +107,7 @@ App::SpreadRevolutionaryDate - Spread date and time from Revolutionary (Republic
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 METHODS
 
@@ -167,6 +167,8 @@ Spreads calendar date to configured targets. Takes no argument.
 
 =item L<App::SpreadRevolutionaryDate::MsgMaker::PromptUser>
 
+=item L<App::SpreadRevolutionaryDate::MsgMaker::Telechat>
+
 =back
 
 =head1 AUTHOR
