@@ -7,26 +7,19 @@
 #
 #   The GNU General Public License, Version 3, June 2007
 #
-#
-# This file is part of App-SpreadRevolutionaryDate
-#
-# This software is Copyright (c) 2019-2024 by Gérald Sédrati.
-#
-# This is free software, licensed under:
-#
-#   The GNU General Public License, Version 3, June 2007
-#
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::BlueskyLite;
-$App::SpreadRevolutionaryDate::BlueskyLite::VERSION = '0.34';
-# ABSTRACT: .
+$App::SpreadRevolutionaryDate::BlueskyLite::VERSION = '0.39';
+# ABSTRACT: Simple Class to post status to BlueSky.
 
 use LWP::UserAgent;
 use DateTime;
 use JSON qw(encode_json decode_json);
 use URI;
 use Encode qw(decode_utf8);
+use File::Type;
+use File::Basename;
 
 use namespace::autoclean;
 
@@ -185,7 +178,7 @@ sub new {
 
 
 sub create_post {
-  my ($self, $text) = @_;
+  my ($self, $text, $img) = @_;
 
   my ($facets, $embed) = $self->_generate_facets($text);
   my $json = encode_json({
@@ -201,6 +194,48 @@ sub create_post {
       createdAt => DateTime->now->iso8601 . 'Z',
     },
   });
+
+  if ($img) {
+    $img = {path => $img} unless ref($img) && ref($img) eq 'HASH' && $img->{path};
+    my $ft = File::Type->new();
+    my $mime_type = $ft->mime_type($img->{path});
+
+    my $img_alt = $img->{alt} // ucfirst(fileparse($img->{path}, qr/\.[^.]*/));
+
+    my $img_bytes;
+    open my $fh, '<', $img->{path} or die "Cannot read $img->{path}: $!\n";
+    {
+        local $/;
+        $img_bytes = <$fh>;
+    }
+    close $fh;
+
+    my $blob_req = HTTP::Request->new('POST', 'https://bsky.social/xrpc/com.atproto.repo.uploadBlob');
+    $blob_req->header('Content-Type' => $mime_type);
+    $blob_req->content($img_bytes);
+    my $blob_response = $self->{ua}->request($blob_req);
+    return unless $blob_response->is_success;
+
+    my $blob_content = decode_json($blob_response->decoded_content);
+    $json = encode_json({
+      repo => $self->{did},
+      collection => 'app.bsky.feed.post',
+      record => {
+        text => $text,
+        embed => {
+          '$type'    => 'app.bsky.embed.images',
+          images => [
+            {
+              alt => $img_alt,
+              image => $blob_content->{blob},
+            },
+          ],
+        },
+        createdAt => DateTime->now->iso8601 . 'Z',
+      },
+    });
+  }
+
   my $req = HTTP::Request->new('POST', 'https://bsky.social/xrpc/com.atproto.repo.createRecord');
   $req->header('Content-Type' => 'application/json');
   $req->content($json);
@@ -224,11 +259,11 @@ __END__
 
 =head1 NAME
 
-App::SpreadRevolutionaryDate::BlueskyLite - .
+App::SpreadRevolutionaryDate::BlueskyLite - Simple Class to post status to BlueSky.
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 Methods
 
@@ -282,6 +317,8 @@ Creates a Bluesky post.
 
 =item L<App::SpreadRevolutionaryDate::MsgMaker::PromptUser>
 
+=item L<App::SpreadRevolutionaryDate::MsgMaker::Telechat>
+
 =back
 
 =head1 AUTHOR
