@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.38';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.39';
 # ABSTRACT: Companion class of L<App::SpreadRevolutionaryDate>, to handle configuration file and command line arguments, subclass of L<AppConfig>.
 
 use Moose;
@@ -339,12 +339,6 @@ Usage: $0 <OPTIONS>
     --msgmaker|-mm <MsgMakerClass>: define message maker (default: RevolutionaryDate)
     --locale|-l <fr|en|it|es>: define locale (default: fr for msgmaker=RevolutionaryDate, en otherwise)
     --test|--no|-n: do not spread, just print out message or spread to test channels for Freenode or Liberachat
-    --acab|-a: DEPRECATED, use --revolutionarydate-acab
-    --bluesksy|-b: DEPRECATED, use --targets=bluesky
-    --twitter|-t: DEPRECATED, use --targets=twitter
-    --mastodon|-m: DEPRECATED, use --targets=mastodon
-    --freenode|-f: DEPRECATED, use --targets=freenode
-    --liberachat|-lt: DEPRECATED, use --targets=liberachat
     --bluesky_identifier|-bi <key>: define Bluesky identifier
     --bluesky_password|-bp <key>: define Bluesky password
     --twitter_consumer_key|-tck <key>: define Twitter consumer key
@@ -392,7 +386,7 @@ App::SpreadRevolutionaryDate::Config - Companion class of L<App::SpreadRevolutio
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 METHODS
 
@@ -468,6 +462,8 @@ Prints usage with command line parameters and exits.
 
 =item L<App::SpreadRevolutionaryDate::MsgMaker::PromptUser>
 
+=item L<App::SpreadRevolutionaryDate::MsgMaker::Telechat>
+
 =back
 
 =head1 AUTHOR
