@@ -10,7 +10,7 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Target::Bluesky;
-$App::SpreadRevolutionaryDate::Target::Bluesky::VERSION = '0.38';
+$App::SpreadRevolutionaryDate::Target::Bluesky::VERSION = '0.39';
 # ABSTRACT: Target class for L<App::SpreadRevolutionaryDate> to handle spreading on Bluesky.
 
 use Moose;
@@ -49,7 +49,7 @@ around BUILDARGS => sub {
 
 
 sub spread {
-  my ($self, $msg, $test) = @_;
+  my ($self, $msg, $test, $img) = @_;
   $test //= 0;
 
   # Multiline message
@@ -58,6 +58,10 @@ sub spread {
   if ($test) {
     $msg = __("Spread on Bluesky: ") . $msg;
 
+    if ($img) {
+      $msg .= " with image path: " . $img->{path} . " , alt: " . $img->{alt};
+    }
+
     use open qw(:std :encoding(UTF-8));
     use IO::Handle;
     my $io = IO::Handle->new;
@@ -68,7 +72,7 @@ sub spread {
 
     $io->say($msg);
   } else {
-    $self->obj->create_post($msg);
+    $self->obj->create_post($msg, $img);
   }
 }
 
@@ -95,7 +99,7 @@ App::SpreadRevolutionaryDate::Target::Bluesky - Target class for L<App::SpreadRe
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 METHODS
 
@@ -151,6 +155,8 @@ Spreads a message to Bluesky. Takes one mandatory argument: C<$msg> which should
 
 =item L<App::SpreadRevolutionaryDate::MsgMaker::PromptUser>
 
+=item L<App::SpreadRevolutionaryDate::MsgMaker::Telechat>
+
 =back
 
 =head1 AUTHOR
